@@ -149,6 +149,7 @@ long cm_RecycleSCache(cm_scache_t *scp, afs_int32 flags)
 
     /* invalidate so next merge works fine;
      * also initialize some flags */
+    scp->fileType = 0;
     scp->flags &= ~(CM_SCACHEFLAG_STATD
 		     | CM_SCACHEFLAG_DELETED
 		     | CM_SCACHEFLAG_RO
@@ -188,7 +189,7 @@ long cm_RecycleSCache(cm_scache_t *scp, afs_int32 flags)
     }
 
     /* discard symlink info */
-    scp->mountPointStringp[0] = 0;
+    scp->mountPointStringp[0] = '\0';
     memset(&scp->mountRootFid, 0, sizeof(cm_fid_t));
     memset(&scp->dotdotFid, 0, sizeof(cm_fid_t));
 
@@ -545,9 +546,9 @@ long cm_GetSCache(cm_fid_t *fidp, cm_scache_t **outScpp, cm_user_t *userp,
     long hash;
     cm_scache_t *scp;
     long code;
-    cm_volume_t *volp = 0;
+    cm_volume_t *volp = NULL;
     cm_cell_t *cellp;
-    char* mp = 0;
+    char* mp = NULL;
     int special; // yj: boolean variable to test if file is on root.afs
     int isRoot;
     extern cm_fid_t cm_rootFid;
@@ -579,7 +580,7 @@ long cm_GetSCache(cm_fid_t *fidp, cm_scache_t **outScpp, cm_user_t *userp,
             return 0;
         }
     }
-        
+
     // yj: when we get here, it means we don't have an scp
     // so we need to either load it or fake it, depending
     // on whether the file is "special", see below.
@@ -631,6 +632,7 @@ long cm_GetSCache(cm_fid_t *fidp, cm_scache_t **outScpp, cm_user_t *userp,
 #endif
         scp->fid = *fidp;
         scp->volp = cm_data.rootSCachep->volp;
+	cm_GetVolume(scp->volp);	/* grab an additional reference */
         scp->dotdotFid.cell=AFS_FAKE_ROOT_CELL_ID;
         scp->dotdotFid.volume=AFS_FAKE_ROOT_VOL_ID;
         scp->dotdotFid.unique=1;
@@ -654,7 +656,7 @@ long cm_GetSCache(cm_fid_t *fidp, cm_scache_t **outScpp, cm_user_t *userp,
         lock_ReleaseMutex(&cm_Freelance_Lock);
 
         scp->owner=0x0;
-        scp->unixModeBits=0x1ff;
+        scp->unixModeBits=0777;
         scp->clientModTime=FakeFreelanceModTime;
         scp->serverModTime=FakeFreelanceModTime;
         scp->parentUnique = 0x1;
@@ -714,6 +716,8 @@ long cm_GetSCache(cm_fid_t *fidp, cm_scache_t **outScpp, cm_user_t *userp,
     if (scp == NULL) {
 	osi_Log0(afsd_logp,"cm_GetNewSCache unable to obtain *new* scache entry");
 	lock_ReleaseWrite(&cm_scacheLock);
+	if (volp)
+	    cm_PutVolume(volp);
 	return CM_ERROR_WOULDBLOCK;
     }
     osi_Log2(afsd_logp,"cm_GetNewSCache returns scp 0x%x flags 0x%x", scp, scp->flags);
@@ -1209,7 +1213,9 @@ void cm_SyncOpDone(cm_scache_t *scp, cm_buf_t *bufp, afs_uint32 flags)
 
     /* now update the buffer pointer */
     if (flags & CM_SCACHESYNC_FETCHDATA) {
-        /* ensure that the buffer isn't already in the I/O list */
+	int release = 0;
+
+	/* ensure that the buffer isn't already in the I/O list */
         for(qdp = scp->bufReadsp; qdp; qdp = (osi_queueData_t *) osi_QNext(&qdp->q)) {
             tbufp = osi_GetQData(qdp);
             if (tbufp == bufp) 
@@ -1218,11 +1224,9 @@ void cm_SyncOpDone(cm_scache_t *scp, cm_buf_t *bufp, afs_uint32 flags)
 	if (qdp) {
 	    osi_QRemove((osi_queue_t **) &scp->bufReadsp, &qdp->q);
 	    osi_QDFree(qdp);
+	    release = 1;
 	}
         if (bufp) {
-	    int release = 0;
-	    if (bufp->cmFlags & CM_BUF_CMFETCHING)
-		release = 1;
             bufp->cmFlags &= ~(CM_BUF_CMFETCHING | CM_BUF_CMFULLYFETCHED);
             if (bufp->flags & CM_BUF_WAITING) {
                 osi_Log2(afsd_logp, "CM SyncOpDone Waking [scp 0x%p] bufp 0x%p", scp, bufp);
@@ -1235,6 +1239,7 @@ void cm_SyncOpDone(cm_scache_t *scp, cm_buf_t *bufp, afs_uint32 flags)
 
     /* now update the buffer pointer */
     if (flags & CM_SCACHESYNC_STOREDATA) {
+	int release = 0;
         /* ensure that the buffer isn't already in the I/O list */
         for(qdp = scp->bufWritesp; qdp; qdp = (osi_queueData_t *) osi_QNext(&qdp->q)) {
             tbufp = osi_GetQData(qdp);
@@ -1244,11 +1249,9 @@ void cm_SyncOpDone(cm_scache_t *scp, cm_buf_t *bufp, afs_uint32 flags)
 	if (qdp) {
 	    osi_QRemove((osi_queue_t **) &scp->bufWritesp, &qdp->q);
 	    osi_QDFree(qdp);
+	    release = 1;
 	}
         if (bufp) {
-	    int release = 0;
-	    if (bufp->cmFlags & CM_BUF_CMSTORING)
-		release = 1;
             bufp->cmFlags &= ~CM_BUF_CMSTORING;
             if (bufp->flags & CM_BUF_WAITING) {
                 osi_Log2(afsd_logp, "CM SyncOpDone Waking [scp 0x%p] bufp 0x%p", scp, bufp);
@@ -1279,7 +1282,9 @@ void cm_SyncOpDone(cm_scache_t *scp, cm_buf_t *bufp, afs_uint32 flags)
  * handled after the callback breaking is done, but only one of whose calls
  * started before that, can cause old info to be merged from the first call.
  */
-void cm_MergeStatus(cm_scache_t *scp, AFSFetchStatus *statusp, AFSVolSync *volp,
+void cm_MergeStatus(cm_scache_t *dscp, 
+		    cm_scache_t *scp, AFSFetchStatus *statusp, 
+		    AFSVolSync *volsyncp,
                     cm_user_t *userp, afs_uint32 flags)
 {
     // yj: i want to create some fake status for the /afs directory and the
@@ -1297,7 +1302,7 @@ void cm_MergeStatus(cm_scache_t *scp, AFSFetchStatus *statusp, AFSVolSync *volp,
         statusp->Owner = 0x0;
         statusp->CallerAccess = 0x9;
         statusp->AnonymousAccess = 0x9;
-        statusp->UnixModeBits = 0x1ff;
+        statusp->UnixModeBits = 0777;
         statusp->ParentVnode = 0x1;
         statusp->ParentUnique = 0x1;
         statusp->ResidencyMask = 0;
@@ -1313,6 +1318,29 @@ void cm_MergeStatus(cm_scache_t *scp, AFSFetchStatus *statusp, AFSVolSync *volp,
     if (statusp->errorCode != 0) {	
 	scp->flags |= CM_SCACHEFLAG_EACCESS;
 	osi_Log2(afsd_logp, "Merge, Failure scp %x code 0x%x", scp, statusp->errorCode);
+
+	scp->fileType = 0;	/* unknown */
+
+	scp->serverModTime = 0;
+	scp->clientModTime = 0;
+	scp->length.LowPart = 0;
+	scp->length.HighPart = 0;
+	scp->serverLength.LowPart = 0;
+	scp->serverLength.HighPart = 0;
+	scp->linkCount = 0;
+	scp->owner = 0;
+	scp->group = 0;
+	scp->unixModeBits = 0;
+	scp->anyAccess = 0;
+	scp->dataVersion = 0;
+
+	if (dscp) {
+            scp->parentVnode = dscp->fid.vnode;
+            scp->parentUnique = dscp->fid.unique;
+	} else {
+            scp->parentVnode = 0;
+            scp->parentUnique = 0;
+	}
 	return;
     } else {
 	scp->flags &= ~CM_SCACHEFLAG_EACCESS;
@@ -1366,6 +1394,7 @@ void cm_MergeStatus(cm_scache_t *scp, AFSFetchStatus *statusp, AFSVolSync *volp,
         if (!(scp->flags & CM_SCACHEFLAG_RO))
             return;
     }       
+
     scp->serverModTime = statusp->ServerModTime;
 
     if (!(scp->mask & CM_SCACHEMASK_CLIENTMODTIME)) {
@@ -1380,7 +1409,6 @@ void cm_MergeStatus(cm_scache_t *scp, AFSFetchStatus *statusp, AFSVolSync *volp,
     scp->serverLength.HighPart = statusp->Length_hi;
 
     scp->linkCount = statusp->LinkCount;
-    scp->dataVersion = statusp->DataVersion;
     scp->owner = statusp->Owner;
     scp->group = statusp->Group;
     scp->unixModeBits = statusp->UnixModeBits & 07777;
@@ -1411,6 +1439,20 @@ void cm_MergeStatus(cm_scache_t *scp, AFSFetchStatus *statusp, AFSVolSync *volp,
     if (userp != NULL) {
         cm_AddACLCache(scp, userp, statusp->CallerAccess);
     }
+
+    if ((flags & CM_MERGEFLAG_STOREDATA) &&
+	statusp->DataVersion - scp->dataVersion == 1) {
+	cm_buf_t *bp;
+
+	for (bp = cm_data.buf_fileHashTablepp[BUF_FILEHASH(&scp->fid)]; bp; bp=bp->fileHashp)
+	{
+	    if (cm_FidCmp(&scp->fid, &bp->fid) == 0 && 
+		bp->dataVersion == scp->dataVersion)
+		bp->dataVersion = statusp->DataVersion;
+	}
+
+    }
+    scp->dataVersion = statusp->DataVersion;
 }
 
 /* note that our stat cache info is incorrect, so force us eventually
@@ -1546,21 +1588,21 @@ int cm_DumpSCache(FILE *outputFile, char *cookie, int lock)
     if (lock)
         lock_ObtainRead(&cm_scacheLock);
   
-    sprintf(output, "%s - dumping scache - cm_data.currentSCaches=%d, cm_data.maxSCaches=%d\n", cookie, cm_data.currentSCaches, cm_data.maxSCaches);
+    sprintf(output, "%s - dumping scache - cm_data.currentSCaches=%d, cm_data.maxSCaches=%d\r\n", cookie, cm_data.currentSCaches, cm_data.maxSCaches);
     WriteFile(outputFile, output, (DWORD)strlen(output), &zilch, NULL);
   
     for (scp = cm_data.scacheLRULastp; scp; scp = (cm_scache_t *) osi_QPrev(&scp->q)) 
     {
         if (scp->refCount != 0)
         {
-            sprintf(output, "%s fid (cell=%d, volume=%d, vnode=%d, unique=%d) refCount=%u\n", 
-                    cookie, scp->fid.cell, scp->fid.volume, scp->fid.vnode, scp->fid.unique, 
+            sprintf(output, "%s scp=0x%p, fid (cell=%d, volume=%d, vnode=%d, unique=%d) refCount=%u\r\n", 
+                    cookie, scp, scp->fid.cell, scp->fid.volume, scp->fid.vnode, scp->fid.unique, 
                     scp->refCount);
             WriteFile(outputFile, output, (DWORD)strlen(output), &zilch, NULL);
         }
     }
   
-    sprintf(output, "%s - dumping cm_data.hashTable - cm_data.hashTableSize=%d\n", cookie, cm_data.hashTableSize);
+    sprintf(output, "%s - dumping cm_data.hashTable - cm_data.hashTableSize=%d\r\n", cookie, cm_data.hashTableSize);
     WriteFile(outputFile, output, (DWORD)strlen(output), &zilch, NULL);
   
     for (i = 0; i < cm_data.hashTableSize; i++)
@@ -1569,7 +1611,7 @@ int cm_DumpSCache(FILE *outputFile, char *cookie, int lock)
         {
             if (scp->refCount != 0)
             {
-                sprintf(output, "%s scp=0x%p, hash=%d, fid (cell=%d, volume=%d, vnode=%d, unique=%d) refCount=%u\n", 
+                sprintf(output, "%s scp=0x%p, hash=%d, fid (cell=%d, volume=%d, vnode=%d, unique=%d) refCount=%u\r\n", 
                          cookie, scp, i, scp->fid.cell, scp->fid.volume, scp->fid.vnode, 
                          scp->fid.unique, scp->refCount);
                 WriteFile(outputFile, output, (DWORD)strlen(output), &zilch, NULL);
@@ -1577,7 +1619,7 @@ int cm_DumpSCache(FILE *outputFile, char *cookie, int lock)
         }
     }
 
-    sprintf(output, "%s - Done dumping scache.\n", cookie);
+    sprintf(output, "%s - Done dumping scache.\r\n", cookie);
     WriteFile(outputFile, output, (DWORD)strlen(output), &zilch, NULL);
   
     if (lock)
