@@ -12,9 +12,10 @@
 
 /* magic file name for ioctl opens */
 #define SMB_IOCTL_FILENAME	"\\_._AFS_IOCTL_._"	/* double backslashes for C compiler */
+#define SMB_IOCTL_FILENAME_NOSLASH "_._AFS_IOCTL_._"
 
 /* max parms for ioctl, in either direction */
-#define SMB_IOCTL_MAXDATA	8192
+#define SMB_IOCTL_MAXDATA	8192*2
 
 #define SMB_IOCTL_MAXPROCS	64			/* max # of calls */
 
@@ -29,6 +30,8 @@ extern long smb_IoctlRead(smb_fid_t *fidp, smb_vc_t *vcp, smb_packet_t *inp, smb
 
 extern long smb_IoctlWrite(smb_fid_t *fidp, smb_vc_t *vcp, smb_packet_t *inp, smb_packet_t *outp);
 
+extern long smb_IoctlV3Write(smb_fid_t *fidp, smb_vc_t *vcp, smb_packet_t *inp, smb_packet_t *outp);
+
 extern long smb_IoctlV3Read(smb_fid_t *fidp, smb_vc_t *vcp, smb_packet_t *inp, smb_packet_t *outp);
 
 #ifndef DJGPP
