@@ -22,7 +22,7 @@
 #include "afs/param.h"
 
 RCSID
-    ("$Header: /cvs/openafs/src/afs/LINUX/osi_vnodeops.c,v 1.126.2.14 2007/04/18 18:20:05 shadow Exp $");
+    ("$Header: /cvs/openafs/src/afs/LINUX/osi_vnodeops.c,v 1.126.2.16 2007/05/17 18:36:02 shadow Exp $");
 
 #include "afs/sysincludes.h"
 #include "afsincludes.h"
@@ -491,11 +491,11 @@ afs_linux_lock(struct file *fp, int cmd, struct file_lock *flp)
 #ifdef AFS_LINUX24_ENV
     if ((code == 0 || flp->fl_type == F_UNLCK) && 
 	(cmd == F_SETLK || cmd == F_SETLKW)) {
-#ifdef AFS_LINUX26_ENV
-	flp->fl_flags &=~ FL_SLEEP;
-	code = posix_lock_file(fp, flp);
+#ifdef POSIX_LOCK_FILE_WAIT_ARG
+        code = posix_lock_file(fp, flp, 0);
 #else
-	code = posix_lock_file(fp, flp, 0);
+        flp->fl_flags &=~ FL_SLEEP;
+        code = posix_lock_file(fp, flp);
 #endif
        if (code && flp->fl_type != F_UNLCK) {
            struct AFS_FLOCK flock2;
