@@ -11,11 +11,10 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/bucoord/main.c,v 1.13 2003/11/23 04:53:30 jaltman Exp $");
+    ("$Header: /cvs/openafs/src/bucoord/main.c,v 1.16.14.2 2007/04/10 18:39:50 shadow Exp $");
 
 #include <afs/stds.h>
 #include <sys/types.h>
-#include <stdio.h>
 #ifdef	AFS_AIX32_ENV
 #include <signal.h>
 #endif
@@ -51,7 +50,6 @@ RCSID
 int localauth, interact;
 char tcell[64];
 
-extern int BC_ExecuteRequest();
 extern int bc_AddDumpCmd();
 extern int bc_AddHostCmd();
 extern int bc_AddVolEntryCmd();
@@ -83,8 +81,6 @@ extern int bc_dumpInfoCmd();
 extern int bc_restoreDbCmd();
 extern int bc_saveDbCmd();
 
-extern PrintError();
-
 /*
  * Global configuration information for the Backup Coordinator.
  */
@@ -255,14 +251,14 @@ backupInit()
 
     /* don't run more than once */
     if (initd) {
-	com_err(whoami, 0, "Backup already initialized.");
+	afs_com_err(whoami, 0, "Backup already initialized.");
 	return 0;
     }
     initd = 1;
 
     code = bc_InitConfig(DefaultConfDir);
     if (code) {
-	com_err(whoami, code,
+	afs_com_err(whoami, code,
 		"Can't initialize from config files in directory '%s'",
 		DefaultConfDir);
 	return (code);
@@ -273,20 +269,20 @@ backupInit()
      */
     code = LWP_InitializeProcessSupport(LWP_NORMAL_PRIORITY, &pid);
     if (code) {
-	com_err(whoami, code, "; Can't initialize LWP");
+	afs_com_err(whoami, code, "; Can't initialize LWP");
 	return (code);
     }
 
     code = rx_Init(htons(0));
     if (code) {
-	com_err(whoami, code, "; Can't initialize Rx");
+	afs_com_err(whoami, code, "; Can't initialize Rx");
 	return (code);
     }
 
     rx_SetRxDeadTime(60);
 
     /* VLDB initialization */
-    vldbClientInit(0, localauth, tcell, &cstruct, &ttoken);
+    code = vldbClientInit(0, localauth, tcell, &cstruct, &ttoken);
     if (code)
 	return (code);
 
@@ -301,7 +297,7 @@ backupInit()
 	LWP_CreateProcess(statusWatcher, 20480, LWP_NORMAL_PRIORITY,
 			  (void *)2, "statusWatcher", &watcherPid);
     if (code) {
-	com_err(whoami, code, "; Can't create status monitor task");
+	afs_com_err(whoami, code, "; Can't create status monitor task");
 	return (code);
     }
 
@@ -345,14 +341,14 @@ MyBeforeProc(as)
 
 	code = backupInit();
 	if (code) {
-	    com_err(whoami, code, "; Can't initialize backup");
+	    afs_com_err(whoami, code, "; Can't initialize backup");
 	    exit(1);
 	}
 
 	/* Get initial information from the database */
 	code = bc_InitTextConfig();
 	if (code) {
-	    com_err(whoami, code,
+	    afs_com_err(whoami, code,
 		    "; Can't obtain configuration text from backup database");
 	    exit(1);
 	}
@@ -413,7 +409,7 @@ doDispatch(targc, targv, dispatchCount)
 
     if (internalLoadFile) {	/* Load a file in */
 	if (dispatchCount > MAXRECURSION) {	/* Beware recursive loops. */
-	    com_err(whoami, 0, "Potential recursion: will not load file %s",
+	    afs_com_err(whoami, 0, "Potential recursion: will not load file %s",
 		    internalLoadFile);
 	    code = -1;
 	    goto done;
@@ -421,7 +417,7 @@ doDispatch(targc, targv, dispatchCount)
 
 	fd = fopen(internalLoadFile, "r");	/* Open the load file */
 	if (!fd) {
-	    com_err(whoami, errno, "; Cannot open file %s", internalLoadFile);
+	    afs_com_err(whoami, errno, "; Cannot open file %s", internalLoadFile);
 	    code = -1;
 	    goto done;
 	}
@@ -448,7 +444,7 @@ doDispatch(targc, targv, dispatchCount)
 		(!noExecute)) {	/*      or no execute */
 		c = cmd_ParseLine(lineBuffer, sargv, &sargc, MAXV);
 		if (c) {
-		    com_err(whoami, c, "; Can't parse line");
+		    afs_com_err(whoami, c, "; Can't parse line");
 		} else {
 		    doDispatch(sargc, sargv, dispatchCount + 1);	/* Recursive - ignore error */
 		    cmd_FreeArgv(sargv);	/* Free up arguments */
@@ -471,6 +467,7 @@ bc_interactCmd(as, arock)
      char *arock;
 {
     interact = 1;
+    return 0;
 }
 
 static void
@@ -799,8 +796,8 @@ main(argc, argv)
 	if (!LineIsBlank(lineBuffer)) {
 	    code = cmd_ParseLine(lineBuffer, targv, &targc, MAXV);
 	    if (code)
-		com_err(whoami, code, "; Can't parse line: '%s'",
-			error_message(code));
+		afs_com_err(whoami, code, "; Can't parse line: '%s'",
+			afs_error_message(code));
 	    else {
 		doDispatch(targc, targv, 1);
 		cmd_FreeArgv(targv);
