@@ -13,7 +13,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/lwp/process.c,v 1.20 2003/07/15 23:15:45 shadow Exp $");
+    ("$Header: /cvs/openafs/src/lwp/process.c,v 1.23.2.1 2007/05/16 20:22:30 shadow Exp $");
 
 #include <stdio.h>
 #include <assert.h>
@@ -33,28 +33,19 @@ extern char PRE_Block;		/* used in lwp.c and process.s */
 afs_int32
 savecontext(char (*ep) (), struct lwp_context *savearea, char *newsp)
 {
-#if defined(AFS_IA64_LINUX20_ENV)
-    register unsigned long sp __asm__("r12");
-#elif defined(AFS_AMD64_LINUX24_ENV)
-    register unsigned long sp __asm__("sp");
-#elif defined(AFS_HPUX1122_ENV)
-/* don't need anything special, will use
- * ucontext.uc_stack.ss_sp as it matches r12.
- * This should also work for Linux,
- * but dont have system to test DEE
- */
-#else
-#error	"You need to update stack pointer register for this platform"
+#if defined(AFS_LINUX20_ENV)
+    /* getcontext does not export stack info */
+    int stackvar;
 #endif
 
     PRE_Block = 1;
 
     savearea->state = 0;
     getcontext(&savearea->ucontext);
-#if defined(AFS_HPUX1122_ENV)
-    savearea->topstack = savearea->ucontext.uc_stack.ss_sp;
+#if defined(AFS_LINUX20_ENV)
+    savearea->topstack = &stackvar;
 #else
-    savearea->topstack = sp;
+    savearea->topstack = savearea->ucontext.uc_stack.ss_sp;
 #endif
     switch (savearea->state) {
     case 0:
@@ -98,10 +89,10 @@ returnto(savearea)
 # else
 #  define LWP_SP JB_SP
 # endif
-#elif	defined(AFS_HPUX_ENV)
+#elif	defined(AFS_HPUX_ENV) || defined(AFS_PARISC_LINUX24_ENV)
 #define	LWP_SP	1
 #elif	defined(AFS_LINUX20_ENV)
-#if defined(AFS_PPC_LINUX20_ENV)
+#if defined(AFS_PPC_LINUX20_ENV) || defined(AFS_PPC64_LINUX20_ENV)
 #define LWP_SP 0
 #elif   defined(AFS_I386_LINUX20_ENV)
 #define LWP_SP 4
@@ -139,7 +130,7 @@ Need offset to SP in jmp_buf for this platform.
 typedef __uint64_t jmp_buf_type;
 #endif
 #else
-#ifdef AFS_ALPHA_LINUX20_ENV
+#if defined(AFS_ALPHA_LINUX20_ENV) || defined(AFS_PPC64_LINUX20_ENV) 
 typedef long jmp_buf_type;
 #else
 typedef int jmp_buf_type;
@@ -151,6 +142,31 @@ static char (*EP) ();
 static int rc;
 static jmp_buf_type *jmpBuffer;
 
+/** Starting with Glibc 2.4 pointers in jmp_buf are mangled (XOR) for "protection".
+  * On Sparc ucontext functions are not implemented.
+  */
+#define ptr_mangle(x) (x)
+#ifdef AFS_LINUX20_ENV
+
+#ifdef __GLIBC__
+#if (__GLIBC__ > 2) || (__GLIBC__ == 2 && __GLIBC_MINOR__ > 3)
+
+#ifdef AFS_SPARC64_LINUX24_ENV
+#undef ptr_mangle
+static int ptr_mangle(int p)
+{   
+    register char *tls_ptr __asm__("%g7");
+    return p ^ *(int*)(tls_ptr + 0x18);
+}
+#else
+#error need ptr_mangle support or use UCONTEXT
+#endif
+
+#endif
+#endif
+#endif
+
+
 afs_int32
 savecontext(ep, savearea, sp)
      char (*ep) ();
@@ -164,7 +180,7 @@ savecontext(ep, savearea, sp)
 
     code = setjmp(savearea->setjmp_buffer);
     jmpBuffer = (jmp_buf_type *) savearea->setjmp_buffer;
-    savearea->topstack = (char *)jmpBuffer[LWP_SP];
+    savearea->topstack = (char *) ptr_mangle(jmpBuffer[LWP_SP]);
 
 #if	defined(DEBUG)
     {
@@ -187,9 +203,9 @@ savecontext(ep, savearea, sp)
 	    switch (rc) {
 	    case 0:
 		jmpBuffer = (jmp_buf_type *) jmp_tmp;
-		jmpBuffer[LWP_SP] = (jmp_buf_type) sp;
+		jmpBuffer[LWP_SP] = ptr_mangle((jmp_buf_type) sp);
 #if defined(AFS_S390_LINUX20_ENV) || defined(AFS_SPARC_LINUX20_ENV) || (defined(AFS_SPARC64_LINUX20_ENV) && defined(AFS_32BIT_USR_ENV))
-		jmpBuffer[LWP_FP] = (jmp_buf_type) sp;
+		jmpBuffer[LWP_FP] = ptr_mangle((jmp_buf_type) sp);
 #endif
 		longjmp(jmp_tmp, 1);
 		break;
