@@ -23,7 +23,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/ptserver/pts.c,v 1.13 2004/06/23 14:27:42 shadow Exp $");
+    ("$Header: /cvs/openafs/src/ptserver/pts.c,v 1.15.2.1 2007/04/10 18:39:54 shadow Exp $");
 
 #include <stdio.h>
 #include <string.h>
@@ -46,6 +46,7 @@ RCSID
 #include "ptclient.h"
 #include "pterror.h"
 #include <afs/afsutil.h>
+#include <afs/com_err.h>
 
 #undef FOREIGN
 
@@ -73,21 +74,21 @@ struct sourcestack {
 } *shead;
 
 int
-Interactive(register struct cmd_syndesc *as)
+Interactive(struct cmd_syndesc *as, char *arock)
 {
     finished = 0;
     return 0;
 }
 
 int
-Quit(register struct cmd_syndesc *as)
+Quit(struct cmd_syndesc *as, char *arock)
 {
     finished = 1;
     return 0;
 }
 
 int
-Source(register struct cmd_syndesc *as)
+Source(struct cmd_syndesc *as, char *arock)
 {
     FILE *fd;
     struct sourcestack *sp;
@@ -115,7 +116,7 @@ Source(register struct cmd_syndesc *as)
 }
 
 int
-Sleep(register struct cmd_syndesc *as)
+Sleep(struct cmd_syndesc *as, char *arock)
 {
     int delay;
     if (!as->parms[0].items) {
@@ -153,7 +154,7 @@ osi_audit()
 }
 
 int
-GetGlobals(register struct cmd_syndesc *as)
+GetGlobals(struct cmd_syndesc *as, char *arock)
 {
     register afs_int32 code;
     char *cell;
@@ -176,7 +177,7 @@ GetGlobals(register struct cmd_syndesc *as)
 	code = pr_Initialize(sec, AFSDIR_CLIENT_ETC_DIRPATH, cell);
     }
     if (code) {
-	com_err(whoami, code, "while initializing");
+	afs_com_err(whoami, code, "while initializing");
 	return code;
     }
     if (as->parms[19].items)
@@ -185,7 +186,7 @@ GetGlobals(register struct cmd_syndesc *as)
 }
 
 int
-CleanUp(register struct cmd_syndesc *as)
+CleanUp(struct cmd_syndesc *as, char *arock)
 {
 #if defined(SUPERGROUPS)
     if (as && !strcmp(as->name, "help"))
@@ -207,7 +208,7 @@ CleanUp(register struct cmd_syndesc *as)
 }
 
 int
-CreateGroup(register struct cmd_syndesc *as)
+CreateGroup(struct cmd_syndesc *as, char *arock)
 {
     register afs_int32 code;
     afs_int32 id;
@@ -226,13 +227,13 @@ CreateGroup(register struct cmd_syndesc *as)
 	if (idi) {
 	    code = util_GetInt32(idi->data, &id);
 	    if (code) {
-		com_err(whoami, code, "because group id was: '%s'",
+		afs_com_err(whoami, code, "because group id was: '%s'",
 			idi->data);
 		return code;
 	    }
 	    if (id >= 0) {
 		code = PRBADARG;
-		com_err(whoami, code, "because group id %d was not negative",
+		afs_com_err(whoami, code, "because group id %d was not negative",
 			id);
 		return code;
 	    }
@@ -249,13 +250,13 @@ CreateGroup(register struct cmd_syndesc *as)
 	code = pr_CreateGroup(namei->data, owner, &id);
 	if (code) {
 	    if (owner || id)
-		com_err(whoami, code,
+		afs_com_err(whoami, code,
 			"; unable to create group %s with id %d%s%s%s%s",
 			namei->data, id, owner ? " owned by '" : "",
 			owner ? owner : "", owner ? "'" : "",
 			(force ? " (ignored)" : ""));
 	    else
-		com_err(whoami, code, "; unable to create group %s %s",
+		afs_com_err(whoami, code, "; unable to create group %s %s",
 			namei->data, (force ? "(ignored)" : ""));
 	    if (!force)
 		return code;
@@ -267,7 +268,7 @@ CreateGroup(register struct cmd_syndesc *as)
 }
 
 int
-CreateUser(register struct cmd_syndesc *as)
+CreateUser(struct cmd_syndesc *as, char *arock)
 {
     register afs_int32 code;
     afs_int32 id;
@@ -281,7 +282,7 @@ CreateUser(register struct cmd_syndesc *as)
 	if (idi) {
 	    code = util_GetInt32(idi->data, &id);
 	    if (code) {
-		com_err(whoami, code, "because id was: '%s'", idi->data);
+		afs_com_err(whoami, code, "because id was: '%s'", idi->data);
 		return code;
 	    }
 	    if (id == 0) {
@@ -295,11 +296,11 @@ CreateUser(register struct cmd_syndesc *as)
 	code = pr_CreateUser(namei->data, &id);
 	if (code) {
 	    if (id)
-		com_err(whoami, code,
+		afs_com_err(whoami, code,
 			"; unable to create user %s with id %d %s",
 			namei->data, id, (force ? "(ignored)" : ""));
 	    else
-		com_err(whoami, code, "; unable to create user %s %s",
+		afs_com_err(whoami, code, "; unable to create user %s %s",
 			namei->data, (force ? "(ignored)" : ""));
 	    if (!force)
 		return code;
@@ -321,11 +322,11 @@ GetNameOrId(register struct cmd_syndesc *as, struct idlist *lids, struct namelis
     int goodCount;
 
     if (!(as->parms[0].items || as->parms[1].items)) {
-	com_err(whoami, 0, "must specify either a name or an id.");
+	afs_com_err(whoami, 0, "must specify either a name or an id.");
 	return -1;
     }
     if (as->parms[0].items && as->parms[1].items) {
-	com_err(whoami, 0, "can't specify both a name and id.");
+	afs_com_err(whoami, 0, "can't specify both a name and id.");
 	return -1;
     }
 
@@ -354,11 +355,11 @@ GetNameOrId(register struct cmd_syndesc *as, struct idlist *lids, struct namelis
 
 	code = pr_NameToId(nl, lids);
 	if (code)
-	    com_err(whoami, code, "so couldn't look up names");
+	    afs_com_err(whoami, code, "so couldn't look up names");
 	else {
 	    for (n = 0; n < lids->idlist_len; n++) {
 		if ((lids->idlist_val[n] == ANONYMOUSID)) {
-		    com_err(whoami, PRNOENT, "so couldn't look up id for %s",
+		    afs_com_err(whoami, PRNOENT, "so couldn't look up id for %s",
 			    nl->namelist_val[n]);
 		} else
 		    goodCount++;
@@ -380,7 +381,7 @@ GetNameOrId(register struct cmd_syndesc *as, struct idlist *lids, struct namelis
 	for (i = as->parms[1].items; i; i = i->next) {
 	    code = util_GetInt32(i->data, &lids->idlist_val[n]);
 	    if (code)
-		com_err(whoami, code =
+		afs_com_err(whoami, code =
 			PRNOENT, "because a bogus id '%s' was specified",
 			i->data);
 	    n++;
@@ -390,7 +391,7 @@ GetNameOrId(register struct cmd_syndesc *as, struct idlist *lids, struct namelis
 	    lnames->namelist_len = 0;
 	    code = pr_IdToName(lids, lnames);
 	    if (code)
-		com_err(whoami, code, "translating ids");
+		afs_com_err(whoami, code, "translating ids");
 	}
     }
     if (code) {
@@ -447,11 +448,11 @@ GetNameOrId(register struct cmd_syndesc *as, struct idlist *lids, struct namelis
     tids.idlist_val = 0;
     code = pr_NameToId(&names, &tids);
     if (code)
-	com_err(whoami, code, "so couldn't look up names");
+	afs_com_err(whoami, code, "so couldn't look up names");
     else {
 	for (n = 0; n < tids.idlist_len; n++) {
 	    if ((tids.idlist_val[n] == ANONYMOUSID)) {
-		com_err(whoami, PRNOENT, "so couldn't look up id for %s",
+		afs_com_err(whoami, PRNOENT, "so couldn't look up id for %s",
 			names.namelist_val[n]);
 	    } else
 		goodCount++;
@@ -470,7 +471,7 @@ GetNameOrId(register struct cmd_syndesc *as, struct idlist *lids, struct namelis
 	tnames.namelist_len = 0;
 	code = pr_IdToName(&ids, &tnames);
 	if (code)
-	    com_err(whoami, code, "translating ids");
+	    afs_com_err(whoami, code, "translating ids");
 	else
 	    goodCount++;
 	if (lnames) {
@@ -492,7 +493,7 @@ GetNameOrId(register struct cmd_syndesc *as, struct idlist *lids, struct namelis
 
 
 int
-AddToGroup(register struct cmd_syndesc *as)
+AddToGroup(struct cmd_syndesc *as, char *arock)
 {
     register afs_int32 code;
     struct cmd_item *u, *g;
@@ -501,7 +502,7 @@ AddToGroup(register struct cmd_syndesc *as)
 	for (g = as->parms[1].items; g; g = g->next) {
 	    code = pr_AddToGroup(u->data, g->data);
 	    if (code) {
-		com_err(whoami, code,
+		afs_com_err(whoami, code,
 			"; unable to add user %s to group %s %s", u->data,
 			g->data, (force ? "(ignored)" : ""));
 		if (!force)
@@ -513,7 +514,7 @@ AddToGroup(register struct cmd_syndesc *as)
 }
 
 int
-RemoveFromGroup(register struct cmd_syndesc *as)
+RemoveFromGroup(struct cmd_syndesc *as, char *arock)
 {
     register afs_int32 code;
     struct cmd_item *u, *g;
@@ -522,7 +523,7 @@ RemoveFromGroup(register struct cmd_syndesc *as)
 	for (g = as->parms[1].items; g; g = g->next) {
 	    code = pr_RemoveUserFromGroup(u->data, g->data);
 	    if (code) {
-		com_err(whoami, code,
+		afs_com_err(whoami, code,
 			"; unable to remove user %s from group %s %s",
 			u->data, g->data, (force ? "(ignored)" : ""));
 		if (!force)
@@ -534,7 +535,7 @@ RemoveFromGroup(register struct cmd_syndesc *as)
 }
 
 int
-ListMembership(register struct cmd_syndesc *as)
+ListMembership(struct cmd_syndesc *as, char *arock)
 {
     register afs_int32 code;
     idlist ids;
@@ -557,7 +558,7 @@ ListMembership(register struct cmd_syndesc *as)
 	list.namelist_len = 0;
 	code = pr_IDListMembers(ids.idlist_val[i], &list);
 	if (code) {
-	    com_err(whoami, code, "; unable to get membership of %s (id: %d)",
+	    afs_com_err(whoami, code, "; unable to get membership of %s (id: %d)",
 		    name, id);
 	    continue;
 	}
@@ -579,7 +580,7 @@ ListMembership(register struct cmd_syndesc *as)
 }
 
 int
-Delete(register struct cmd_syndesc *as)
+Delete(struct cmd_syndesc *as, char *arock)
 {
     register afs_int32 code;
     idlist ids;
@@ -598,7 +599,7 @@ Delete(register struct cmd_syndesc *as)
 
 	code = pr_DeleteByID(id);
 	if (code) {
-	    com_err(whoami, code, "deleting %s (id: %d) %s", name, id,
+	    afs_com_err(whoami, code, "deleting %s (id: %d) %s", name, id,
 		    (force ? "(ignored)" : ""));
 	    if (!force)
 		return code;
@@ -618,7 +619,7 @@ char *flags_dncase = "s mar";	/* legal member acces values */
 int flags_shift[5] = { 2, 1, 2, 2, 1 };	/* bits for each */
 
 int
-CheckEntry(register struct cmd_syndesc *as)
+CheckEntry(struct cmd_syndesc *as, char *arock)
 {
     register afs_int32 code;
     afs_int32 rcode = 1;
@@ -646,7 +647,7 @@ CheckEntry(register struct cmd_syndesc *as)
 	code = pr_ListEntry(id, &aentry);
 	if (code) {
 	    rcode = code;
-	    com_err(whoami, code, "; unable to find entry for (id: %d)", id);
+	    afs_com_err(whoami, code, "; unable to find entry for (id: %d)", id);
 	    continue;
 	}
 
@@ -655,7 +656,7 @@ CheckEntry(register struct cmd_syndesc *as)
 	code = pr_IdToName(&lids, &lnames);
 	if (code) {
 	    rcode = code;
-	    com_err(whoami, code,
+	    afs_com_err(whoami, code,
 		    "translating owner (%d) and creator (%d) ids",
 		    aentry.owner, aentry.creator);
 	    continue;
@@ -717,7 +718,7 @@ CheckEntry(register struct cmd_syndesc *as)
 }
 
 int
-ListEntries(struct cmd_syndesc *as)
+ListEntries(struct cmd_syndesc *as, char *arock)
 {
     afs_int32 code = 0;
     afs_int32 flag, startindex, nentries, nextstartindex;
@@ -736,7 +737,7 @@ ListEntries(struct cmd_syndesc *as)
 	    pr_ListEntries(flag, startindex, &nentries, &entriesp,
 			   &nextstartindex);
 	if (code) {
-	    com_err(whoami, code, "; unable to list entries\n");
+	    afs_com_err(whoami, code, "; unable to list entries\n");
 	    if (entriesp)
 		free(entriesp);
 	    break;
@@ -754,7 +755,7 @@ ListEntries(struct cmd_syndesc *as)
 }
 
 int
-ChownGroup(register struct cmd_syndesc *as)
+ChownGroup(struct cmd_syndesc *as, char *arock)
 {
     register afs_int32 code;
     char *name;
@@ -764,13 +765,13 @@ ChownGroup(register struct cmd_syndesc *as)
     owner = as->parms[1].items->data;
     code = pr_ChangeEntry(name, "", 0, owner);
     if (code)
-	com_err(whoami, code, "; unable to change owner of %s to %s", name,
+	afs_com_err(whoami, code, "; unable to change owner of %s to %s", name,
 		owner);
     return code;
 }
 
 int
-ChangeName(register struct cmd_syndesc *as)
+ChangeName(struct cmd_syndesc *as, char *arock)
 {
     register afs_int32 code;
     char *oldname;
@@ -780,24 +781,24 @@ ChangeName(register struct cmd_syndesc *as)
     newname = as->parms[1].items->data;
     code = pr_ChangeEntry(oldname, newname, 0, "");
     if (code)
-	com_err(whoami, code, "; unable to change name of %s to %s", oldname,
+	afs_com_err(whoami, code, "; unable to change name of %s to %s", oldname,
 		newname);
     return code;
 }
 
 int
-ListMax(register struct cmd_syndesc *as)
+ListMax(struct cmd_syndesc *as, char *arock)
 {
     register afs_int32 code;
     afs_int32 maxUser, maxGroup;
 
     code = pr_ListMaxUserId(&maxUser);
     if (code)
-	com_err(whoami, code, "getting maximum user id");
+	afs_com_err(whoami, code, "getting maximum user id");
     else {
 	code = pr_ListMaxGroupId(&maxGroup);
 	if (code)
-	    com_err(whoami, code, "getting maximum group id");
+	    afs_com_err(whoami, code, "getting maximum group id");
 	else {
 	    printf("Max user id is %d and max group id is %d.\n", maxUser,
 		   maxGroup);
@@ -807,7 +808,7 @@ ListMax(register struct cmd_syndesc *as)
 }
 
 int
-SetMax(register struct cmd_syndesc *as)
+SetMax(struct cmd_syndesc *as, char *arock)
 {
     register afs_int32 code;
     afs_int32 maxid;
@@ -817,12 +818,12 @@ SetMax(register struct cmd_syndesc *as)
 	/* set user max */
 	code = util_GetInt32(as->parms[1].items->data, &maxid);
 	if (code) {
-	    com_err(whoami, code, "because id was: '%s'",
+	    afs_com_err(whoami, code, "because id was: '%s'",
 		    as->parms[1].items->data);
 	} else {
 	    code = pr_SetMaxUserId(maxid);
 	    if (code)
-		com_err(whoami, code, "so couldn't set Max User Id to %d",
+		afs_com_err(whoami, code, "so couldn't set Max User Id to %d",
 			maxid);
 	}
     }
@@ -830,12 +831,12 @@ SetMax(register struct cmd_syndesc *as)
 	/* set group max */
 	code = util_GetInt32(as->parms[0].items->data, &maxid);
 	if (code) {
-	    com_err(whoami, code, "because id was: '%s'",
+	    afs_com_err(whoami, code, "because id was: '%s'",
 		    as->parms[0].items->data);
 	} else {
 	    code = pr_SetMaxGroupId(maxid);
 	    if (code)
-		com_err(whoami, code, "so couldn't set Max Group Id to %d",
+		afs_com_err(whoami, code, "so couldn't set Max Group Id to %d",
 			maxid);
 	}
     }
@@ -847,13 +848,13 @@ SetMax(register struct cmd_syndesc *as)
 }
 
 int
-SetFields(register struct cmd_syndesc *as)
+SetFields(struct cmd_syndesc *as, char *arock)
 {
     register afs_int32 code;
     idlist ids;
     namelist names;
     int i;
-    afs_int32 mask, flags, ngroups, nusers;
+    afs_int32 mask, flags=0, ngroups, nusers;
 
     if (GetNameOrId(as, &ids, &names))
 	return PRBADARG;
@@ -904,7 +905,7 @@ SetFields(register struct cmd_syndesc *as)
     if (as->parms[2].items) {	/* limitgroups */
 	code = util_GetInt32(as->parms[2].items->data, &ngroups);
 	if (code) {
-	    com_err(whoami, code, "because ngroups was: '%s'",
+	    afs_com_err(whoami, code, "because ngroups was: '%s'",
 		    as->parms[2].items->data);
 	    return code;
 	}
@@ -914,7 +915,7 @@ SetFields(register struct cmd_syndesc *as)
     if (as->parms[3].items) {	/* limitgroups */
 	code = util_GetInt32(as->parms[3].items->data, &nusers);
 	if (code) {
-	    com_err(whoami, code, "because nusers was: '%s'",
+	    afs_com_err(whoami, code, "because nusers was: '%s'",
 		    as->parms[3].items->data);
 	    return code;
 	}
@@ -929,7 +930,7 @@ SetFields(register struct cmd_syndesc *as)
 	    continue;
 	code = pr_SetFieldsEntry(id, mask, flags, ngroups, nusers);
 	if (code) {
-	    com_err(whoami, code, "; unable to set fields for %s (id: %d)",
+	    afs_com_err(whoami, code, "; unable to set fields for %s (id: %d)",
 		    name, id);
 	    return code;
 	}
@@ -942,7 +943,7 @@ SetFields(register struct cmd_syndesc *as)
 }
 
 int
-ListOwned(register struct cmd_syndesc *as)
+ListOwned(struct cmd_syndesc *as, char *arock)
 {
     register afs_int32 code;
     idlist ids;
@@ -971,7 +972,7 @@ ListOwned(register struct cmd_syndesc *as)
 	    list.namelist_len = 0;
 	    code = pr_ListOwned(oid, &list, &more);
 	    if (code) {
-		com_err(whoami, code,
+		afs_com_err(whoami, code,
 			"; unable to get owner list for %s (id: %d)", name,
 			oid);
 		break;
@@ -1162,7 +1163,7 @@ main(int argc, char **argv)
 #if defined(SUPERGROUPS)
     finished = 1;
     if (code = cmd_Dispatch(argc, argv)) {
-	CleanUp(0);
+	CleanUp(NULL, NULL);
 	exit(1);
     }
     source = stdin;
@@ -1188,7 +1189,7 @@ main(int argc, char **argv)
 	    cmd_ParseLine(line, parsev, &parsec,
 			  sizeof(parsev) / sizeof(*parsev));
 	if (code) {
-	    com_err(whoami, code, "parsing line: <%s>", line);
+	    afs_com_err(whoami, code, "parsing line: <%s>", line);
 	    exit(2);
 	}
 	savec = parsev[0];
@@ -1197,7 +1198,7 @@ main(int argc, char **argv)
 	parsev[0] = savec;
 	cmd_FreeArgv(parsev);
     }
-    CleanUp(0);
+    CleanUp(NULL, NULL);
     exit(0);
 
 #else /* SUPERGROUPS */
