@@ -15,7 +15,7 @@
 #include "afs/param.h"
 
 RCSID
-    ("$Header: /cvs/openafs/src/rx/rx_kcommon.c,v 1.56.2.2 2006/08/31 04:52:16 shadow Exp $");
+    ("$Header: /cvs/openafs/src/rx/rx_kcommon.c,v 1.56.2.4 2007/02/09 00:18:45 shadow Exp $");
 
 #include "rx/rx_kcommon.h"
 
@@ -520,7 +520,7 @@ shutdown_rxkernel(void)
 int
 rxi_GetcbiInfo(void)
 {
-    int i, j, different = 0;
+    int i, j, different = 0, num = ADDRSPERSITE;
     int rxmtu, maxmtu;
     afs_uint32 ifinaddr;
     afs_uint32 addrs[ADDRSPERSITE];
@@ -529,7 +529,9 @@ rxi_GetcbiInfo(void)
     memset((void *)addrs, 0, sizeof(addrs));
     memset((void *)mtus, 0, sizeof(mtus));
 
-    for (i = 0; i < afs_cb_interface.numberOfInterfaces; i++) {
+    if (afs_cb_interface.numberOfInterfaces < num)
+	num = afs_cb_interface.numberOfInterfaces;
+    for (i = 0; i < num; i++) {
 	if (!afs_cb_interface.mtu[i])
 	    afs_cb_interface.mtu[i] = htonl(1500);
 	rxmtu = (ntohl(afs_cb_interface.mtu[i]) - RX_IPUDP_SIZE);
@@ -635,11 +637,13 @@ rxi_GetIFInfo(void)
     afs_uint32 ifinaddr;
 #if defined(AFS_DARWIN80_ENV)
     errno_t t;
-    int cnt=0;
-    ifaddr_t *ifads, ifad;
-    register ifnet_t ifn;
+    unsigned int count;
+    int cnt=0, m, j;
+    ifaddr_t *ifads;
+    ifnet_t *ifn;
     struct sockaddr sout;
     struct sockaddr_in *sin;
+    struct in_addr pin;
 #else
     struct ifaddr *ifad;	/* ifnet points to a if_addrlist of ifaddrs */
     register struct ifnet *ifn;
@@ -649,31 +653,38 @@ rxi_GetIFInfo(void)
     memset(mtus, 0, sizeof(mtus));
 
 #if defined(AFS_DARWIN80_ENV)
-    t = ifnet_get_address_list_family(NULL, &ifads, AF_INET);
-    if (t == 0) {
-	rxmtu = ifnet_mtu(ifn) - RX_IPUDP_SIZE;
-	while((ifads[cnt] != NULL) && cnt < ADDRSPERSITE) {
-	    t = ifaddr_address(ifads[cnt], &sout, sizeof(sout));
-	    sin = (struct sockaddr_in *)&sout;
-	    ifinaddr = ntohl(sin->sin_addr.s_addr);
-	    if (myNetAddrs[i] != ifinaddr) {
-		different++;
+    if (!ifnet_list_get(AF_INET, &ifn, &count)) {
+	for (m = 0; m < count; m++) {
+	    if (!ifnet_get_address_list(ifn[m], &ifads)) {
+		for (j = 0; ifads[j] != NULL && cnt < ADDRSPERSITE; j++) {
+		    if ((t = ifaddr_address(ifads[j], &sout, sizeof(struct sockaddr))) == 0) {
+			sin = (struct sockaddr_in *)&sout;
+			rxmtu = ifnet_mtu(ifaddr_ifnet(ifads[j])) - RX_IPUDP_SIZE;
+			ifinaddr = ntohl(sin->sin_addr.s_addr);
+			if (myNetAddrs[i] != ifinaddr) {
+			    different++;
+			}
+			mtus[i] = rxmtu;
+			rxmtu = rxi_AdjustIfMTU(rxmtu);
+			maxmtu =
+			    rxmtu * rxi_nRecvFrags +
+			    ((rxi_nRecvFrags - 1) * UDP_HDR_SIZE);
+			maxmtu = rxi_AdjustMaxMTU(rxmtu, maxmtu);
+			addrs[i++] = ifinaddr;
+			if ((ifinaddr != 0x7f000001) && 
+			    (maxmtu > rx_maxReceiveSize)) {
+			    rx_maxReceiveSize = 
+				MIN(RX_MAX_PACKET_SIZE, maxmtu);
+			    rx_maxReceiveSize =
+				MIN(rx_maxReceiveSize, rx_maxReceiveSizeUser);
+			}
+			cnt++;
+		    }
+		}
+		ifnet_free_address_list(ifads);
 	    }
-	    mtus[i] = rxmtu;
-	    rxmtu = rxi_AdjustIfMTU(rxmtu);
-	    maxmtu =
-		rxmtu * rxi_nRecvFrags +
-		((rxi_nRecvFrags - 1) * UDP_HDR_SIZE);
-	    maxmtu = rxi_AdjustMaxMTU(rxmtu, maxmtu);
-	    addrs[i++] = ifinaddr;
-	    if ((ifinaddr != 0x7f000001) && (maxmtu > rx_maxReceiveSize)) {
-		rx_maxReceiveSize = MIN(RX_MAX_PACKET_SIZE, maxmtu);
-		rx_maxReceiveSize =
-		    MIN(rx_maxReceiveSize, rx_maxReceiveSizeUser);
-	    }
-	    cnt++;
 	}
-	ifnet_free_address_list(ifads);
+	ifnet_list_free(ifn);
     }
 #else
 #if defined(AFS_DARWIN_ENV) || defined(AFS_FBSD_ENV)
@@ -729,10 +740,10 @@ rxi_GetIFInfo(void)
     rx_maxJumboRecvSize = MAX(rx_maxJumboRecvSize, rx_maxReceiveSize);
 
     if (different) {
-	int j;
-	for (j = 0; j < i; j++) {
-	    myNetMTUs[j] = mtus[j];
-	    myNetAddrs[j] = addrs[j];
+	int l;
+	for (l = 0; l < i; l++) {
+	    myNetMTUs[l] = mtus[l];
+	    myNetAddrs[l] = addrs[l];
 	}
     }
     return different;
